@@ -93,7 +93,6 @@
 #include "mbfl_language.h"
 #include "mbfl_string.h"
 #include "mbfl_convert.h"
-#include "mbfl_ident.h"
 
 /* Prefer local fix, otherwise need to include too much. */
 #ifndef ssize_t
@@ -155,8 +154,14 @@ MBFLAPI extern size_t mbfl_buffer_illegalchars(mbfl_buffer_converter *convd);
  */
 typedef struct _mbfl_encoding_detector mbfl_encoding_detector;
 
+typedef struct {
+	size_t num_illegalchars;
+	size_t score;
+} mbfl_encoding_detector_data;
+
 struct _mbfl_encoding_detector {
-	mbfl_identify_filter **filter_list;
+	mbfl_convert_filter **filter_list;
+	mbfl_encoding_detector_data *filter_data;
 	int filter_list_size;
 	int strict;
 };
@@ -290,7 +295,7 @@ MBFLAPI extern mbfl_string *
 mbfl_html_numeric_entity(mbfl_string *string, mbfl_string *result, int *convmap, int mapsize, int type);
 
 /*
- * convert of harfwidth and fullwidth for japanese
+ * convert of halfwidth and fullwidth for japanese
  */
 MBFLAPI extern mbfl_string *
 mbfl_ja_jp_hantozen(mbfl_string *string, mbfl_string *result, int mode);
